@@ -33,25 +33,33 @@ val length : t -> int
 
 (** {2 Access} *)
 
-external get : t -> int -> char = "%caml_ba_ref_1"
+val get : t -> int -> char
   (** [get buffer offset] returns the byte at offset [offset] in
       [buffer]. *)
 
-external set : t -> int -> char -> unit = "%caml_ba_set_1"
+val set : t -> int -> char -> unit
   (** [get buffer offset value] changes the value of the byte at
       offset [offset] in [buffer] to [value]. *)
 
-external unsafe_get : t -> int -> char = "%caml_ba_unsafe_ref_1"
-  (** Same as {!get} but without bound checking. *)
+val unsafe_get : t -> int -> char
+  (** Same as {!get} but without bounds checking. *)
 
-external unsafe_set : t -> int -> char -> unit = "%caml_ba_unsafe_set_1"
-  (** Same as {!set} but without bound checking. *)
+val unsafe_set : t -> int -> char -> unit
+  (** Same as {!set} but without bounds checking. *)
 
 (** {2 Conversions} *)
 
+val of_bytes : Bytes.t -> t
+  (** [of_bytes buf] returns a newly allocated byte array with the
+      same contents as [buf]. *)
+
 val of_string : string -> t
-  (** [of_string str] returns a newly allocated byte array with the
-      same contents as [str]. *)
+  (** [of_string buf] returns a newly allocated byte array with the
+      same contents as [buf]. *)
+
+val to_bytes : t -> Bytes.t
+  (** [to_bytes buf] returns newly allocated bytes with the same
+      contents as [buf]. *)
 
 val to_string : t -> string
   (** [to_string buf] returns a newly allocated string with the same
@@ -60,25 +68,25 @@ val to_string : t -> string
 (** {2 Copying} *)
 
 val blit : t -> int -> t -> int -> int -> unit
-  (** [blit buf1 ofs1 buf2 ofs2 len] copy [len] bytes from [buf1]
+  (** [blit buf1 ofs1 buf2 ofs2 len] copies [len] bytes from [buf1]
       starting at offset [ofs1] to [buf2] starting at offset [ofs2]. *)
 
-val blit_string_bytes : string -> int -> t -> int -> int -> unit
-  (** Same as blit but the first buffer is a string instead of a byte
+val blit_from_bytes : Bytes.t -> int -> t -> int -> int -> unit
+  (** Same as {!blit} but the first buffer is a string instead of a byte
       array. *)
 
-val blit_bytes_string : t -> int -> string -> int -> int -> unit
-  (** Same as blit but the second buffer is a string instead of a byte
+val blit_to_bytes : t -> int -> Bytes.t -> int -> int -> unit
+  (** Same as {!blit} but the second buffer is a string instead of a byte
       array. *)
 
-external unsafe_blit : t -> int -> t -> int -> int -> unit = "lwt_unix_blit_bytes_bytes" "noalloc"
+val unsafe_blit : t -> int -> t -> int -> int -> unit
   (** Same as {!blit} but without bound checking. *)
 
-external unsafe_blit_string_bytes : string -> int -> t -> int -> int -> unit = "lwt_unix_blit_string_bytes" "noalloc"
-  (** Same as {!blit_string_bytes} but without bound checking. *)
+val unsafe_blit_from_bytes : Bytes.t -> int -> t -> int -> int -> unit
+  (** Same as {!blit_string_bytes} but without bounds checking. *)
 
-external unsafe_blit_bytes_string : t -> int -> string -> int -> int -> unit = "lwt_unix_blit_bytes_string" "noalloc"
-  (** Same as {!blit_bytes_string} but without bound checking. *)
+val unsafe_blit_to_bytes : t -> int -> Bytes.t -> int -> int -> unit
+  (** Same as {!blit_bytes_string} but without bounds checking. *)
 
 val proxy : t -> int -> int -> t
   (** [proxy buffer offset length] creates a ``proxy''. The returned
@@ -100,12 +108,12 @@ val fill : t -> int -> int -> char -> unit
       bytes of [buffer] starting at offset [offset]. *)
 
 external unsafe_fill : t -> int -> int -> char -> unit = "lwt_unix_fill_bytes" "noalloc"
-  (** Same as {!fill} but without bound checking. *)
+  (** Same as {!fill} but without bounds checking. *)
 
 (** {2 IOs} *)
 
-(** The following functions does the same as the functions in
-    {!Lwt_unix} except that they use byte arrays instead of
+(** The following functions behave similarly to the ones in
+    {!Lwt_unix} except they use byte arrays instead of
     strings. *)
 
 val read : Lwt_unix.file_descr -> t -> int -> int -> int Lwt.t
@@ -142,7 +150,7 @@ external mapped : t -> bool = "lwt_unix_mapped" "noalloc"
       file. *)
 
 (** Type of advise that can be sent to the kernel by the program. See
-    the manual madvise(2) for a description of each advices. *)
+    the manual madvise(2) for a description of each. *)
 type advice =
   | MADV_NORMAL
   | MADV_RANDOM
@@ -151,9 +159,9 @@ type advice =
   | MADV_DONTNEED
 
 val madvise : t -> int -> int -> advice -> unit
-  (** [madvise buffer pos len advice] advise the kernel about how the
-      program is going to use the part of the memory mapped file
-      between [pos] and [pos + len].
+  (** [madvise buffer pos len advice] advises the kernel how the
+      program will use the memory mapped file between [pos] and
+      [pos + len].
 
       This call is not available on windows. *)
 
@@ -164,13 +172,13 @@ val mincore : t -> int -> bool array -> unit
   (** [mincore buffer offset states] tests whether the given pages are
       in the system memory (the RAM). The [offset] argument must be a
       multiple of {!page_size}. [states] is used to store the result;
-      each cases is [true] if the corresponding page in the RAM and
+      each cases is [true] if the corresponding page is in RAM and
       [false] otherwise.
 
-      This call is not available on windows. *)
+      This call is not available on windows and cygwin. *)
 
 val wait_mincore : t -> int -> unit Lwt.t
   (** [wait_mincore buffer offset] waits until the page containing the
-      byte at offset [offset] in the the RAM.
+      byte at offset [offset] is in RAM.
 
-      This functions is not available on windows. *)
+      This functions is not available on windows and cygwin. *)
