@@ -13,6 +13,8 @@
 #define HAVE_GETPEEREID
 #define HAVE_FDATASYNC
 //#define HAVE_NETDB_REENTRANT
+//#define HAVE_REENTRANT_HOSTENT
+#define NANOSEC(buf, field) buf->st_##field##tim.tv_nsec
 #if defined(HAVE_GET_CREDENTIALS_LINUX) || defined(HAVE_GET_CREDENTIALS_NETBSD) || defined(HAVE_GET_CREDENTIALS_OPENBSD) || defined(HAVE_GET_CREDENTIALS_FREEBSD) || defined(HAVE_GETPEEREID)
 #  define HAVE_GET_CREDENTIALS
 #endif
