@@ -103,21 +103,33 @@ val null : output_channel
 
 (** {2 Channels creation/manipulation} *)
 
-val pipe : ?buffer_size : int -> unit -> input_channel * output_channel
-  (** [pipe ?buffer_size ()] creates a pipe using {!Lwt_unix.pipe} and
-      makes two channels from the two returned file descriptors *)
+val pipe : ?in_buffer : Lwt_bytes.t -> ?out_buffer : Lwt_bytes.t -> unit ->
+  input_channel * output_channel
+  (** [pipe ?in_buffer ?out_buffer ()] creates a pipe using
+      {!Lwt_unix.pipe} and makes two channels from the two returned file
+      descriptors *)
 
 val make :
-  ?buffer_size : int ->
+  ?buffer : Lwt_bytes.t ->
   ?close : (unit -> unit Lwt.t) ->
   ?seek : (int64 -> Unix.seek_command -> int64 Lwt.t) ->
   mode : 'mode mode ->
   (Lwt_bytes.t -> int -> int -> int Lwt.t) -> 'mode channel
-  (** [make ?buffer_size ?close ~mode perform_io] is the
+  (** [make ?buffer ?close ~mode perform_io] is the
       main function for creating new channels.
 
-      @param buffer_size size of the internal buffer. It must be
-      between 16 and [Sys.max_string_length]
+      @param buffer user-supplied buffer. When this argument is
+      present, its value will be used as the buffer for the created
+      channel. The size of buffer must conform to the limitations
+      described in {!set_default_buffer_size}.  When this argument is
+      not present, a new internal buffer of default size will be
+      allocated for this channel.
+
+      Warning: do not use the same buffer for simultaneous work with more
+      than one channel.
+
+      There are other functions in this module that take a [buffer]
+      argument, sharing the same semantics.
 
       @param close close function of the channel. It defaults to
       [Lwt.return]
@@ -134,16 +146,18 @@ val of_bytes : mode : 'mode mode -> Lwt_bytes.t -> 'mode channel
   (** Create a channel from a byte array. Reading/writing is done
       directly on the provided array. *)
 
-val of_fd : ?buffer_size : int -> ?close : (unit -> unit Lwt.t) -> mode : 'mode mode -> Lwt_unix.file_descr -> 'mode channel
-  (** [of_fd ?buffer_size ?close ~mode fd] creates a channel from a
+val of_fd : ?buffer : Lwt_bytes.t -> ?close : (unit -> unit Lwt.t) ->
+  mode : 'mode mode -> Lwt_unix.file_descr -> 'mode channel
+  (** [of_fd ?buffer ?close ~mode fd] creates a channel from a
       file descriptor.
 
       @param close defaults to closing the file descriptor. *)
 
-val of_unix_fd : ?buffer_size : int -> ?close : (unit -> unit Lwt.t) -> mode : 'mode mode -> Unix.file_descr -> 'mode channel
-  (** [of_unix_fd ?buffer_size ?close ~mode fd] is a short-hand for:
+val of_unix_fd : ?buffer : Lwt_bytes.t -> ?close : (unit -> unit Lwt.t) ->
+  mode : 'mode mode -> Unix.file_descr -> 'mode channel
+  (** [of_unix_fd ?buffer ?close ~mode fd] is a short-hand for:
 
-      [of_fd ?buffer_size ?close (Lwt_unix.of_unix_file_descr fd)] *)
+      [of_fd ?buffer ?close (Lwt_unix.of_unix_file_descr fd)] *)
 
 val close : 'a channel -> unit Lwt.t
   (** [close ch] closes the given channel. If [ch] is an output
@@ -240,7 +254,7 @@ val read_lines : input_channel -> string Lwt_stream.t
   (** [read_lines ic] returns a stream holding all lines of [ic] *)
 
 val read : ?count : int -> input_channel -> string Lwt.t
-  (** [read ?count ic] reads at most [len] characters from [ic]. It
+  (** [read ?count ic] reads at most [count] characters from [ic]. It
       returns [""] if the end of input is reached. If [count] is not
       specified, it reads all bytes until the end of input. *)
 
@@ -352,12 +366,12 @@ type file_name = string
     (** Type of file names *)
 
 val open_file :
-  ?buffer_size : int ->
+  ?buffer : Lwt_bytes.t ->
   ?flags : Unix.open_flag list ->
   ?perm : Unix.file_perm ->
   mode : 'a mode ->
   file_name -> 'a channel Lwt.t
-  (** [open_file ?buffer_size ?flags ?perm ~mode filename] opens the
+  (** [open_file ?buffer ?flags ?perm ~mode filename] opens the
       file with name [filename] and returns a channel for
       reading/writing it.
 
@@ -365,34 +379,36 @@ val open_file :
   *)
 
 val with_file :
-  ?buffer_size : int ->
+  ?buffer : Lwt_bytes.t ->
   ?flags : Unix.open_flag list ->
   ?perm : Unix.file_perm ->
   mode : 'a mode ->
   file_name -> ('a channel -> 'b Lwt.t) -> 'b Lwt.t
-  (** [with_file ?buffer_size ?flags ?perm ~mode filename f] opens a
+  (** [with_file ?buffer ?flags ?perm ~mode filename f] opens a
       file and passes the channel to [f]. It is ensured that the
       channel is closed when [f ch] terminates (even if it fails). *)
 
 val open_connection :
   ?fd : Lwt_unix.file_descr ->
-  ?buffer_size : int -> Unix.sockaddr -> (input_channel * output_channel) Lwt.t
-(** [open_connection ?fd ?buffer_size addr] opens a connection to the
-    given address and returns two channels for using it. If [fd] is
-    not specified, a fresh one will be used.
+  ?in_buffer : Lwt_bytes.t -> ?out_buffer : Lwt_bytes.t ->
+  Unix.sockaddr -> (input_channel * output_channel) Lwt.t
+  (** [open_connection ?fd ?in_buffer ?out_buffer addr] opens a
+      connection to the given address and returns two channels for using
+      it. If [fd] is not specified, a fresh one will be used.
 
-    The connection is completly closed when you close both
-    channels.
+      The connection is completly closed when you close both
+      channels.
 
-    @raise Unix.Unix_error on error.
-*)
+      @raise Unix.Unix_error on error.
+  *)
 
 val with_connection :
   ?fd : Lwt_unix.file_descr ->
-  ?buffer_size : int ->
+  ?in_buffer : Lwt_bytes.t -> ?out_buffer : Lwt_bytes.t ->
   Unix.sockaddr -> (input_channel * output_channel -> 'a Lwt.t) -> 'a Lwt.t
-(** [with_connection ?fd ?buffer_size addr f] opens a connection to
-      the given address and passes the channels to [f] *)
+  (** [with_connection ?fd ?in_buffer ?out_buffer addr f] opens a
+      connection to the given address and passes the channels to
+      [f] *)
 
 type server
   (** Type of a server *)
@@ -402,12 +418,13 @@ val establish_server :
   ?buffer_size : int ->
   ?backlog : int ->
   Unix.sockaddr -> (input_channel * output_channel -> unit) -> server
-(** [establish_server ?fd ?buffer_size ?backlog sockaddr f] creates a
-    server which will listen for incoming connections. New connections
-    are passed to [f]. Note that [f] must not raise any exception. If
-    [fd] is not specified, a fresh file descriptor will be created.
+  (** [establish_server ?fd ?buffer_size ?backlog sockaddr f] creates
+      a server which will listen for incoming connections. New
+      connections are passed to [f]. Note that [f] must not raise any
+      exception. If [fd] is not specified, a fresh file descriptor will
+      be created.
 
-    [backlog] is the argument passed to [Lwt_unix.listen] *)
+      [backlog] is the argument passed to [Lwt_unix.listen] *)
 
 val shutdown_server : server -> unit
   (** Shutdown the given server *)
@@ -516,7 +533,7 @@ val direct_access : 'a channel -> (direct_access -> 'b Lwt.t) -> 'b Lwt.t
 
 val default_buffer_size : unit -> int
   (** Return the default size for buffers. Channels that are created
-      without a specific size use this one. *)
+      without a specific buffer use new buffer of this size. *)
 
 val set_default_buffer_size : int -> unit
   (** Change the default buffer size.
